<?php

require_once("Home.php"); // including home controller

/**
* class admin_config
* @category controller
*/
class Dashboard extends Home
{
    /**
    * load constructor method
    * @access public
    * @return void
    */
    public function __construct()
    {
        parent::__construct();

        if ($this->session->userdata('logged_in')!= 1) {
            redirect('home/login_page', 'location');
        }

        $this->important_feature();
        $this->periodic_check();
   }

    /**
    * load index method. redirect to config
    * @access public
    * @return void
    */
    public function index()
    {
        $total_enabled_bot = $this->basic->get_data('messenger_bot_page_info',['where'=>['user_id'=>$this->user_id,'bot_enabled'=>'1']],['count(id) as total_enabled_bot']);
        $total_errors_in_bot = $this->basic->get_data('messenger_bot_reply_error_log',['where'=>['user_id'=>$this->user_id]],['count(id) as total_errors_in_bot']);
        $total_enabled_persistent_menu = $this->basic->get_data('messenger_bot_page_info',['where'=>['user_id'=>$this->user_id,'persistent_enabled'=>'1']],['count(id) as total_enabled_persistent_menu']);
        $total_subscribers = $this->basic->get_data('messenger_bot_subscriber',['where'=>['user_id'=>$this->user_id]],['count(id) as total_subscribers']);
        $total_male_subscribers = $this->basic->get_data('messenger_bot_subscriber',['where'=>['user_id'=>$this->user_id,'gender'=>'male']],['count(id) as total_subscribers']);
        $total_female_subscribers = $this->basic->get_data('messenger_bot_subscriber',['where'=>['user_id'=>$this->user_id,'gender'=>'female']],['count(id) as total_subscribers']);

        $gender_type_data = array(
            0 => array(
                "value" => $total_male_subscribers[0]['total_subscribers'],
                "color" => '#FFCF75',
                "highlight" => '#FFCF75',
                "label" => $this->lang->line('Male subscriber')
            ),
            1 => array(
                "value" => $total_female_subscribers[0]['total_subscribers'],
                "color" => '#FF8000',
                "highlight" => '#FF8000',
                "label" => $this->lang->line('Female subscriber')
            )
        );
        $data['gender_type_data'] = $gender_type_data;
        $data['total_male_subscribers'] = $total_male_subscribers[0]['total_subscribers'];
        $data['total_female_subscribers'] = $total_female_subscribers[0]['total_subscribers'];
         


        $data['total_enabled_bot'] = $total_enabled_bot[0]['total_enabled_bot'];
        $data['total_errors_in_bot'] = $total_errors_in_bot[0]['total_errors_in_bot'];
        $data['total_enabled_persistent_menu'] = $total_enabled_persistent_menu[0]['total_enabled_persistent_menu'];
        $data['total_subscribers'] = $total_subscribers[0]['total_subscribers'];

        $curdate=date("Y-m-d");
        $from_date=date('Y-m-d', strtotime($curdate. " - 30 days"));
        $from_date = $from_date." 00:00:00";
        $to_date = $curdate." 23:59:59";
        $where = array();
        $where['where'] = array(
            "subscribed_at >=" => $from_date,
            "subscribed_at <=" => $to_date,
            "gender" => 'male',
            "user_id" => $this->user_id
            );
        $select = array(
            "date_format(subscribed_at,'%Y-%m-%d') as date",
            "count(id) as number_of_subscriber"
            );
        $day_wise_male_subscribers = $this->basic->get_data('messenger_bot_subscriber',$where,$select,$join='',$limit='',$start='',$order_by='',$group_by="date");
        $male_subscribers = array();
        foreach($day_wise_male_subscribers as $value)
        {
            $male_subscribers[$value['date']] = $value['number_of_subscriber'];
        }

        $where = array();
        $where['where'] = array(
            "subscribed_at >=" => $from_date,
            "subscribed_at <=" => $to_date,
            "gender" => 'female',
            "user_id" => $this->user_id
            );
        $select = array(
            "date_format(subscribed_at,'%Y-%m-%d') as date",
            "count(id) as number_of_subscriber"
            );
        $day_wise_female_subscribers = $this->basic->get_data('messenger_bot_subscriber',$where,$select,$join='',$limit='',$start='',$order_by='',$group_by="date");
        $female_subscribers = array();
        foreach($day_wise_female_subscribers as $value)
        {
            $female_subscribers[$value['date']] = $value['number_of_subscriber'];
        }

        $subscribers_comparison_data = array();
        $total_subscribers_data = array();

        $dDiff = strtotime($to_date) - strtotime($from_date);
        $no_of_days = floor($dDiff/(60*60*24));
        
        for($i=0;$i<=$no_of_days;$i++){
            $day_count = date('Y-m-d', strtotime($from_date. " + $i days"));

            if(isset($male_subscribers[$day_count]))
            {
                $daily_male_subscribers = $male_subscribers[$day_count];
                $subscribers_comparison_data[$i]['date'] = $day_count;
                $subscribers_comparison_data[$i]['male'] = $daily_male_subscribers;
            }
            else
            {
                $daily_male_subscribers = 0;
                $subscribers_comparison_data[$i]['date'] = $day_count;
                $subscribers_comparison_data[$i]['male'] = $daily_male_subscribers;
            }

            if(isset($female_subscribers[$day_count]))
            {
                $daily_female_subscribers = $female_subscribers[$day_count];
                $subscribers_comparison_data[$i]['date'] = $day_count;
                $subscribers_comparison_data[$i]['female'] = $daily_female_subscribers;
            }
            else
            {
                $daily_female_subscribers = 0;
                $subscribers_comparison_data[$i]['date'] = $day_count;
                $subscribers_comparison_data[$i]['female'] = $daily_female_subscribers;
            }

            $total_subscribers_data[$i]['date'] = $day_count;
            $total_subscribers_data[$i]['subscribers'] = $daily_male_subscribers + $daily_female_subscribers;

        }

        $data['subscribers_comparison_data'] = $subscribers_comparison_data;
        $data['total_subscribers_data'] = $total_subscribers_data;


        $where = array();
        $where['where'] = array(
            "last_update_time >=" => $from_date,
            "last_update_time <=" => $to_date,
            "user_id" => $this->user_id
            );
        $select = array(
            "date_format(last_update_time,'%Y-%m-%d') as date",
            "count(id) as number_of_emails"
            );
        $day_wise_email_gain = $this->basic->get_data('messenger_bot_quick_reply_email',$where,$select,$join='',$limit='',$start='',$order_by='',$group_by="date");
        $email_gain = array();
        foreach($day_wise_email_gain as $value)
        {
            $email_gain[$value['date']] = $value['number_of_emails'];
        }
        $day_wise_total_email = array();
        for($i=0;$i<=$no_of_days;$i++){
            $day_count = date('Y-m-d', strtotime($from_date. " + $i days"));

            if(isset($email_gain[$day_count]))
            {
                $total_emails = $email_gain[$day_count];
                $day_wise_total_email[$i]['date'] = $day_count;
                $day_wise_total_email[$i]['emails'] = $total_emails;
            }
            else
            {
                $total_emails = 0;
                $day_wise_total_email[$i]['date'] = $day_count;
                $day_wise_total_email[$i]['emails'] = $total_emails;
            }

        }

        $total_emails_gain = $this->basic->get_data('messenger_bot_quick_reply_email',['where'=>['user_id'=>$this->user_id]],['count(id) as number_of_emails']);
        $data['total_emails'] = $total_emails_gain[0]['number_of_emails'];

        $data['day_wise_total_email'] = $day_wise_total_email;

        $data['body'] = 'dashboard';
        $this->_viewcontroller($data);
    }


}
